@@ -2,7 +2,7 @@ package Plack::App::Directory::Markdown;
 use strict;
 use warnings;
 use utf8;
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use parent 'Plack::App::Directory';
 use Plack::App::Directory::Markdown::Static;
@@ -11,6 +11,7 @@ use Data::Section::Simple;
 use Text::Xslate;
 use HTTP::Date;
 use URI::Escape qw/uri_escape/;
+use Plack::Builder;
 
 use Plack::Util::Accessor;
 Plack::Util::Accessor::mk_accessors(__PACKAGE__, qw(title tx tx_path markdown_class markdown_ext));
@@ -30,6 +31,18 @@ sub new {
     $self;
 }
 
+sub to_app {
+    my $self = shift;
+
+    my $app = $self->SUPER::to_app;
+    my $static_app = Plack::App::Directory::Markdown::Static->new->to_app;
+
+    builder {
+        mount '/_static' => $static_app,
+        mount '/'        => $app,
+    };
+}
+
 sub markdown {
     my $self = shift;
 
@@ -43,71 +56,9 @@ sub markdown {
     $md->markdown(@_);
 }
 
-sub should_handle {
-    my($self, $file) = @_;
-    return -d $file || -f $file || $file =~ m!(?:^|/)_static/!;
-}
-
-sub locate_file {
-    my($self, $env) = @_;
-
-    my $path = $env->{PATH_INFO} || '';
-
-    if ($path =~ /\0/) {
-        return $self->return_400;
-    }
-
-    my $docroot = $self->root || ".";
-    my @path = split '/', $path;
-    if (@path) {
-        shift @path if $path[0] eq '';
-    } else {
-        @path = ('.');
-    }
-
-    if (grep $_ eq '..', @path) {
-        return $self->return_403;
-    }
-
-    my($file, @path_info);
-    while (@path) {
-        my $try = File::Spec::Unix->catfile($docroot, @path);
-        if ($self->should_handle($try)) {
-            $file = $try;
-            last;
-        } elsif (!$self->allow_path_info) {
-            last;
-        }
-        unshift @path_info, pop @path;
-    }
-
-    if (!$file) {
-        return $self->return_404;
-    }
-
-    if (!-r $file && $file !~ m!(?:^|/)_static/! ) {
-        return $self->return_403;
-    }
-
-    return $file, join("/", "", @path_info);
-}
-
 sub serve_path {
     my($self, $env, $dir) = @_;
 
-    if ($dir =~ m!(?:^|/)_static/!) {
-        my $static_file = $self->remove_root_path($dir);
-        $static_file =~ s!^_static/!!;
-        my ($data, $mime_type) = Plack::App::Directory::Markdown::Static::get_data($static_file);
-
-        return $self->return_404 unless $data;
-
-        return [ 200, [
-            'Content-Type'   => $mime_type,
-            'Content-Length' => length($data),
-        ], [ $data ] ];
-    }
-
     if (-f $dir) {
         if ($self->is_markdown($dir)) {
             my $content = do {local $/;open my $fh,'<:encoding(UTF-8)',$dir or die $!;<$fh>};
